pub trait Poller { // Required method fn poll(&mut self) -> Result<!>; }
A trait representing a poller that performs periodic tasks.
This trait’s poll method returns an error if the polling operation fails.
poll
Polls for periodic tasks.
Returns an error if the polling operation fails.